==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridCellValueChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { ColumnDescriptionMetadata } from "./ColumnDescriptionMetadata";
import { GridCellValueChangingEventArgsDescription } from "./GridCellValueChangingEventArgsDescription";
/**
 * @hidden
 */
var GridCellValueChangingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridCellValueChangingEventArgsDescriptionMetadata, _super);
    function GridCellValueChangingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridCellValueChangingEventArgsDescriptionMetadata.b = function (a) {
        if (GridCellValueChangingEventArgsDescriptionMetadata.a == null) {
            GridCellValueChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridCellValueChangingEventArgsDescriptionMetadata.c(GridCellValueChangingEventArgsDescriptionMetadata.a);
        }
        if (a.g(GridCellValueChangingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridCellValueChangingEventArgsDescriptionMetadata.a);
        CellInfoDescriptionMetadata.d(a);
        ColumnDescriptionMetadata.d(a);
    };
    GridCellValueChangingEventArgsDescriptionMetadata.c = function (a) {
        a.item("EditID", "Number:int");
        a.item("CellInfo", "ExportedType:CellModel");
        a.item("Column", "ExportedType:Column");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("OldValue", "Unknown");
        a.item("NewValue", "Unknown");
    };
    GridCellValueChangingEventArgsDescriptionMetadata.d = function (a) {
        GridCellValueChangingEventArgsDescriptionMetadata.b(a);
        a.u("GridCellValueChangingEventArgs", function () { return new GridCellValueChangingEventArgsDescription(); });
        a.t("GridCellValueChangingEventArgs", GridCellValueChangingEventArgsDescriptionMetadata.a);
    };
    GridCellValueChangingEventArgsDescriptionMetadata.$t = markType(GridCellValueChangingEventArgsDescriptionMetadata, 'GridCellValueChangingEventArgsDescriptionMetadata');
    GridCellValueChangingEventArgsDescriptionMetadata.a = null;
    return GridCellValueChangingEventArgsDescriptionMetadata;
}(Base));
export { GridCellValueChangingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridCellValueChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridCellValueChangingEventArgsDescription } from "./GridCellValueChangingEventArgsDescription";
/**
 * @hidden
 */
var GridCellValueChangingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridCellValueChangingEventArgsDescriptionMetadata, _super);
    function GridCellValueChangingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridCellValueChangingEventArgsDescriptionMetadata.b = function (a) {
        if (GridCellValueChangingEventArgsDescriptionMetadata.a == null) {
            GridCellValueChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridCellValueChangingEventArgsDescriptionMetadata.c(GridCellValueChangingEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridCellValueChangingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridCellValueChangingEventArgsDescriptionMetadata.a);
        CellInfoDescriptionMetadata.d(a);
        DataGridColumnDescriptionMetadata.d(a);
    };
    GridCellValueChangingEventArgsDescriptionMetadata.c = function (a) {
        a.item("EditID", "Number:int");
        a.item("CellInfo", "ExportedType:CellModel");
        a.item("Column", "ExportedType:DataGridColumn");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("OldValue", "Unknown");
        a.item("NewValue", "Unknown");
    };
    GridCellValueChangingEventArgsDescriptionMetadata.d = function (a) {
        GridCellValueChangingEventArgsDescriptionMetadata.b(a);
        a.aa("GridCellValueChangingEventArgs", function () { return new GridCellValueChangingEventArgsDescription(); });
        a.z("GridCellValueChangingEventArgs", GridCellValueChangingEventArgsDescriptionMetadata.a);
    };
    GridCellValueChangingEventArgsDescriptionMetadata.$t = markType(GridCellValueChangingEventArgsDescriptionMetadata, 'GridCellValueChangingEventArgsDescriptionMetadata');
    GridCellValueChangingEventArgsDescriptionMetadata.a = null;
    return GridCellValueChangingEventArgsDescriptionMetadata;
}(Base));
export { GridCellValueChangingEventArgsDescriptionMetadata };
